# 🙌 Advanced Features

The library does not only encapsulate the Odin API methods it also has other features built in. The scripter object gives you access to pre-written scripts of common tasks and features not built in Odin's web portal such as locating an alias.&#x20;

Other features such as a data store, reports, and broadwork entities are being worked on in development.&#x20;
